==> fasttest-0.0.8.tar.gz: fasttest-0.0.8/fasttest/runner/test_case.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
import re
import unittest
import traceback
from fasttest.common import *


class TestCase(unittest.TestCase):
    def __getattr__(self, item):
        try:
            return self.__getattribute__(item)
        except:
            attrvalue = None
            self.__setattr__(item, attrvalue)
            return attrvalue

    def __init__(self, methodName="runTest"):
        super(TestCase, self).__init__(methodName)
        if not Var.testcase:
            raise NameError("name 'testcase' is not defined")
        for key, value in Var.testcase.items():
            setattr(self, key, value)
        self.snapshot_dir = os.path.join(Var.report, self.module, self.testcase_path.split(os.sep)[-1].split(".")[0])

    def run(self, result=None):

        try:
            Var.case_step_index = 0
            Var.case_snapshot_index = 0
            Var.testcase_steps = []
            Var.snapshot_dir = self.snapshot_dir
            if not os.path.exists(Var.snapshot_dir):
                os.makedirs(Var.snapshot_dir)
            log_info("******************* TestCase {} Start *******************".format(self.description))
            with open(self.testcase_path, 'r') as r:
                s = r.readlines()
                index = s.index('steps:\n')
                for step in s[index+1:]:
                    if not (step.lstrip().startswith('#') or re.match('#', step.lstrip().lstrip('-').lstrip())):
                        if step != '\n':
                            Var.testcase_steps.append(step)
            unittest.TestCase.run(self, result)
            Var.testcase_steps = []
            log_info("******************* Total: {}, Pass: {}, Failed: {}, Error: {}, Skipped: {} ********************\n"
                    .format(result.testsRun, len(result.successes), len(result.failures), len(result.errors), len(result.skipped)))
        except:
            traceback.print_exc()

==> fasttest-1.0.1.tar.gz: fasttest-1.0.1/fasttest/runner/test_case.py <==
#!/usr/bin/env python3
# -*- coding: utf-8 -*-
import os
import re
import unittest
import traceback
from fasttest.common import *


class TestCase(unittest.TestCase):
    def __getattr__(self, item):
        try:
            return self.__getattribute__(item)
        except:
            attrvalue = None
            self.__setattr__(item, attrvalue)
            return attrvalue

    def __init__(self, methodName="runTest"):
        super(TestCase, self).__init__(methodName)
        for key, value in Var.case_info.items():
            setattr(self, key, value)
        self.snapshot_dir = os.path.join(Var.report,'Steps', self.module, self.test_case_path.split('/')[-1].split(os.sep)[-1].split(".")[0])
        self.report = Var.report

    def run(self, result=None):

        try:
            Var.case_step_index = 0
            Var.case_snapshot_index = 0
            Var.snapshot_dir = self.snapshot_dir
            testcase_steps = []
            if not os.path.exists(Var.snapshot_dir):
                os.makedirs(Var.snapshot_dir)
            with open(self.test_case_path, 'r', encoding='UTF-8') as r:
                s = r.readlines()
                index = s.index('steps:\n')
                for step in s[index+1:]:
                    if not (step.lstrip().startswith('#') or re.match('#', step.lstrip().lstrip('-').lstrip())):
                        if step != '\n':
                            testcase_steps.append(step)
            log_info("******************* TestCase {} Start *******************".format(self.description))
            unittest.TestCase.run(self, result)
            log_info("******************* Total: {}, Success: {}, Failed: {}, Error: {}, Skipped: {} ********************\n"
                    .format(result.testsRun, len(result.successes), len(result.failures), len(result.errors), len(result.skipped)))
        except:
            traceback.print_exc()
